Learn R Programming

WikiSocio (version 0.7.0)

contrib_list: Getting the list of the contribution of a contributor.

Description

Getting the list of the contribution of a contributor.

Usage

contrib_list(x, namespace = "0", domain = "fr", page = F)

Arguments

x
The name of the contributor
namespace
The namespace of contributions
domain
The domain of the wiki
page
If TRUE, contrib_list return only a list of all different page in witch the contribors made a modification. If FALSE, return a data-frame with all the contributions, their timestamp and their weight

Value

Depending the value of page, weither a character vector containing the names of all contributors, or a data-frame containing all the revisions with the name of the contributor, a timestamp and a weight

Examples

Run this code

# All the contribution of an user of the french wiki.
contrib_list('cafeine05') 

# Return a character vector with all the page modified by this contributor.
contrib_list('cafeine05',page=TRUE) 

Run the code above in your browser using DataLab