Learn R Programming

WikiSocio (version 0.7.0)

corpus_contrib_create: Creating a contributor corpus

Description

Creating a contributor corpus

Usage

corpus_contrib_create(method, x, limit = "max", domain = "fr")

Arguments

method
The method employed to get data into the corpus.
category
Every contributor page included in the category x would be included in the corpus
random
Select x random contributor page

xpath
x is a vector containing in first position the URL of one page, and in second position the wpath request to apply to this URL. Will return a list of words, wich are the names of the contributors if the xpath request is writed correctly

x
The pointer of the method.
limit
If not 'max', then an integer giving the corpus size. Useless for random method.
domain
The domain where the wiki is located.

Value

A character vector

See Also

corpus_contrib_data to put data into the corpus you made with this function, corpus_contrib_select to clean the corpus with a specific criteria

Other corpus functions: corpus_contrib_data, corpus_contrib_select, corpus_page_create, corpus_page_data

Examples

Run this code
# Creating a contributor corpus formed by contributors of the 'Action' page on the french wiki.
corpus_contrib_create('page','Action')

# Same as previous, by limiting the size of the corpus at 5 contributors.
corpus_contrib_create('page','Action',limit=5)

Run the code above in your browser using DataLab