Learn R Programming

WikiSocio (version 0.7.0)

corpus_contrib_select: Selecting the member of a corpus, based on their contributions.

Description

This function is used to have a corpus of big contributors of the wiki. To use this, you need a contributor corpus completed with 'page' method of corpus_contrib_data

Usage

corpus_contrib_select(method, x, threesold, domain = "fr")

Arguments

method
Method employed to get data into the corpus.
firstContrib
Select only contributors who are part of the threesold % of first contibutor of each page

x
A corpus created with corpus_contrib_create
threesold
An integer used as a threesold to decide weither a contributor can be on the corpus or not. For instance, if threesold=5, only contribor who are is in the 5 percent first contributor of the article.
domain
The domain where the wiki is located

Value

A data-frame.

Details

BE CAUTIOUS : this function is VERY time-consuming.

See Also

Other corpus functions: corpus_contrib_create, corpus_contrib_data, corpus_page_create, corpus_page_data

Examples

Run this code
# creating a corpus of 5 contributor of the action page
c <- corpus_contrib_create('page','Action',limit=5)

c <- corpus_contrib_data('page',c)

# Keeping on this corpus only the contributor who are part of
# the 5 percent first contributors of the correspondant article.
c <- corpus_contrib_select(c,5)

Run the code above in your browser using DataLab