Learn R Programming

WikiSocio (version 0.7.0)

corpus_page_create: Creating a page corpus

Description

Creating a page corpus

Usage

corpus_page_create(method, x, limit = "max", domain = "fr")

Arguments

method
The method employed to create the corpus.
category
Every page in the category x is included to the corpus

random
Select x random page

xpath
x is a vector containing in first position the URL of one page, and in second position the wpath request to apply to this URL. Will return a list of words, wich are the names of pages if the xpath request is writed correctly

x
The pointer of the method.
limit
If not 'max', then an integer giving the length of the corpus. Useless for random method.
domain
The domain where the wiki is located

Value

A character vector.

See Also

corpus_contrib_create for contributors corpus, corpus_page_data to put data into the corpus you made with this function

Other corpus functions: corpus_contrib_create, corpus_contrib_data, corpus_contrib_select, corpus_page_data

Examples

Run this code
# Creating a page corpus formed by 3 random selected page
corpus_page_create('random',3)

Run the code above in your browser using DataLab