Learn R Programming

WikiSocio (version 0.7.0)

page_anon: Giving the proportion of anonmous contribution in a revisions list

Description

Giving the proportion of anonmous contribution in a revisions list

Usage

page_anon(revisions)

Arguments

revisions
Revision list built with page_revisions

Value

An integer.

See Also

Other page functions: page_infos, page_islink, page_links, page_ranking, page_revisions

Examples

Run this code
# Downloading the list of the revisions of the article 'Action' in the french wiki
revisions <- page_revisions('Action') 

# Returning the percentage of anonymous contribution in this article
page_anon(revisions) 

Run the code above in your browser using DataLab