Learn R Programming

WikiSocio (version 0.7.0)

page_islink: Test if page(s) is(are) linked

Description

Test if page(s) is(are) linked

Usage

page_islink(from, to, namespace = "0", domain = "fr")

Arguments

from
The title of the page from the link is supposed to go from
to
Either a string or a character vector representing the page(s) where the link(s) is(are) supposed to go to.
namespace
The namespace of the page to look.
domain
The domain where the wiki is located

Value

A character vector.

See Also

Other page functions: page_anon, page_infos, page_links, page_ranking, page_revisions

Examples

Run this code
# Testing if the article 'Action' contains a link to 'Sociologie' in the french wiki.
page_islink('Action','Sociologie') 

Run the code above in your browser using DataLab