Learn R Programming

WikiSocio (version 0.7.0)

page_links: List of inter-articles links on a wiki page

Description

List of inter-articles links on a wiki page

Usage

page_links(x, domain = "fr", namespace = "0")

Arguments

x
The title of the page
domain
The domain of the wiki where the page is located
namespace
The namespace where the page need to be to be ept in the graph

Value

A character vector

See Also

Other page functions: page_anon, page_infos, page_islink, page_ranking, page_revisions

Examples

Run this code
page_links('Action') # listing all the links contained in the 'action' article.

Run the code above in your browser using DataLab