Learn R Programming

WikiSocio (version 0.7.0)

page_ranking: Extracting the first contributors freom a list of revisions

Description

Extracting the first contributors freom a list of revisions

Usage

page_ranking(revisions, threesold, keepAnon = TRUE)

Arguments

revisions
A list of revisions built with page_revisions
threesold
An integer, he function will return the threesold percent first contributors
keepAnon
A boolean indicate weither the anonymous should be kept into the list or not

Value

A character vector

See Also

Other page functions: page_anon, page_infos, page_islink, page_links, page_revisions

Examples

Run this code
# Downloading the list of revisions
revisions <- page_revisions('Action')

# Extracting the list of the 10 percent first contributor of the list
page_ranking(revisions,10,TRUE) 

Run the code above in your browser using DataLab