Learn R Programming

WikiSocio (version 0.7.0)

page_revisions: Downloading the list of contributions for one page

Description

Downloading the list of contributions for one page

Usage

page_revisions(page, domain = "fr", contrib = F)

Arguments

page
The title of the page
domain
The domain where the wiki is located
contrib
A boolean indicating whether to return or not only contributors' names

Value

A data-frame containing the username of the user (or the IP if anonymous contribution), the timestamp, the size of the revision, a boolean indicating weither the contribution is anonymous or not, and the difference beetween the contribution and the previous

See Also

Other page functions: page_anon, page_infos, page_islink, page_links, page_ranking

Examples

Run this code
# Downloading the list of contribution for the 'action' page in the french wiki
page_revisions('Action') 

Run the code above in your browser using DataLab