If TRUE, contrib_list return only a list of all different page in witch the contribors made a modification. If FALSE, return a data-frame with all the contributions, their timestamp and their weight
Value
Depending the value of page, weither a character vector containing the names of all contributors, or a data-frame containing all the revisions with the name of the contributor, a timestamp and a weight
# All the contribution of an user of the french wiki.contrib_list('cafeine05')
# Return a character vector with all the page modified by this contributor.contrib_list('cafeine05',page=TRUE)