# Creating a contributor corpus formed by contributors of the 'Action' page on the french wiki.
corpus_contrib_create('page','Action')
# Same as previous, by limiting the size of the corpus at 5 contributors.
corpus_contrib_create('page','Action',limit=5)
Run the code above in your browser using DataLab