Every page in the category x is included to the corpus
random
Select x random page
xpath
x is a vector containing in first position the URL of one page,
and in second position the wpath request to apply to this URL.
Will return a list of words, wich are the names of pages if the xpath request is writed correctly
x
The pointer of the method.
limit
If not 'max', then an integer giving the length of the corpus. Useless for random method.