# Downloading the list of the revisions of the article 'Action' in the french wiki
revisions <- page_revisions('Action')
# Returning the percentage of anonymous contribution in this article
page_anon(revisions)
Run the code above in your browser using DataLab