page_revisions: Downloading the list of contributions for one page
Description
Downloading the list of contributions for one page
Usage
page_revisions(page, domain = "fr", contrib = F)
Arguments
page
The title of the page
domain
The domain where the wiki is located
contrib
A boolean indicating whether to return or not only contributors' names
Value
A data-frame containing the username of the user (or the IP if anonymous contribution), the timestamp, the size of the revision, a boolean indicating weither the contribution is anonymous or not, and the difference beetween the contribution and the previous